godev/internal/content: update TestServer_ServeHTTP to require go1.28

TestServer_ServeHTTP//noindex relies on the exact output of
http.FileServer, which was changed in CL 795560.

Update the test to match the new output, and run TestServer_ServeHTTP
only at gotip, which should provide enough coverage.

Fixes golang/go#80652

Change-Id: I476f8a8880729854bfe0979a2f114c326a6a6964
Reviewed-on: https://go-review.googlesource.com/c/telemetry/+/808320
Reviewed-by: Michael Matloob <matloob@google.com>
Reviewed-by: Nicholas Husin <husin@google.com>
LUCI-TryBot-Result: golang-scoped@luci-project-accounts.iam.gserviceaccount.com <golang-scoped@luci-project-accounts.iam.gserviceaccount.com>
Reviewed-by: Michael Matloob <matloob@golang.org>
Reviewed-by: Richard Miller <millerresearch@gmail.com>
diff --git a/godev/internal/content/testdata/noindex/noindex.html.out b/godev/internal/content/testdata/noindex/noindex.html.out
index 9ed564a..b763309 100644
--- a/godev/internal/content/testdata/noindex/noindex.html.out
+++ b/godev/internal/content/testdata/noindex/noindex.html.out
@@ -1,5 +1,6 @@
 <!doctype html>
 <meta name="viewport" content="width=device-width">
+<meta name="color-scheme" content="light dark">
 <pre>
 <a href="noindex.html.out">noindex.html.out</a>
 </pre>
diff --git a/godev/internal/content/content_test.go b/godev/internal/content/content_test.go
index 192b8e0..ef521e8 100644
--- a/godev/internal/content/content_test.go
+++ b/godev/internal/content/content_test.go
@@ -21,7 +21,7 @@
 )
 
 func TestServer_ServeHTTP(t *testing.T) {
-	testenv.NeedsGo1Point(t, 23) // output of some http helpers changed in Go 1.23
+	testenv.NeedsGo1Point(t, 28) // output of some http helpers changed in Go 1.28
 	fsys := os.DirFS("testdata")
 
 	// Reset the default logger after this test.